diff --git a/search_api.api.php b/search_api.api.php
index bbab2ab..58dc3f3 100644
--- a/search_api.api.php
+++ b/search_api.api.php
@@ -138,8 +138,8 @@ function hook_search_api_views_handler_mapping_alter(array &$mapping) {
  *
  * @param array $mapping
  *   An associative array with property data types as the keys and Views field
- *   handler definitions as the values (i.e., just the inner "field" portion of
- *   Views data definition items). In some cases the value might also be NULL
+ *   handler definitions as the values (that is, just the inner "field" portion
+ *   of Views data definition items). In some cases the value might also be NULL
  *   instead, to indicate that properties of this type shouldn't have field
  *   handlers. The data types in the keys might also contain asterisks (*) as
  *   wildcard characters. Data types with wildcards will be matched only if no
diff --git a/search_api.module b/search_api.module
index 4b5d7b9..d6748fc 100644
--- a/search_api.module
+++ b/search_api.module
@@ -24,7 +24,7 @@ use Drupal\search_api\Task\IndexTaskManager;
 function search_api_help($route_name) {
   switch ($route_name) {
     case 'search_api.overview':
-      return t('Below is a list of indexes grouped by the server they are associated with. A server is the definition of the actual indexing, querying and storage engine (e.g., an Apache Solr server, the database, …). An index defines the indexed content (e.g., all content and all comments on "Article" posts).');
+      return t('Below is a list of indexes grouped by the server they are associated with. A server is the definition of the actual indexing, querying and storage engine (for example, an Apache Solr server, the database, …). An index defines the indexed content (for example, all content and all comments on "Article" posts).');
   }
   return NULL;
 }
diff --git a/search_api.theme.inc b/search_api.theme.inc
index e8895d2..5e6e264 100644
--- a/search_api.theme.inc
+++ b/search_api.theme.inc
@@ -394,7 +394,7 @@ function theme_search_api_index($variables) {
       // server for this index. Therefore we circumvent the whole preprocessing
       // (which could add facets, access filters, etc.) and hand the query
       // directly to the server.
-      // @todo Add a cleaner way for doing this (i.e., skipping preprocessing).
+      // @todo Add a cleaner way for doing this (that is, skipping preprocessing).
       $query = $index->query();
       $query->range(0, 0);
       // Tag this special query to allow backend plugins to treat this query
diff --git a/src/Datasource/DatasourceInterface.php b/src/Datasource/DatasourceInterface.php
index 6543b6d..1272e06 100644
--- a/src/Datasource/DatasourceInterface.php
+++ b/src/Datasource/DatasourceInterface.php
@@ -200,9 +200,9 @@ interface DatasourceInterface extends IndexPluginInterface {
    *   implemented by this datasource; or NULL to retrieve all items at once.
    *
    * @return string[]|null
-   *   An array with datasource-specific (i.e., not prefixed with the datasource
-   *   ID) item IDs; or NULL if there are no more items for this and all
-   *   following pages.
+   *   An array with datasource-specific (that is, not prefixed with the
+   *   datasource ID) item IDs; or NULL if there are no more items for this and
+   *   all following pages.
    */
   public function getItemIds($page = NULL);
 
diff --git a/src/Entity/Index.php b/src/Entity/Index.php
index 3adf14c..2c71933 100644
--- a/src/Entity/Index.php
+++ b/src/Entity/Index.php
@@ -865,8 +865,8 @@ class Index extends ConfigEntityBase implements IndexInterface {
     // Check whether there are requested items that couldn't be loaded.
     $items_by_datasource = array_filter($items_by_datasource);
     if ($items_by_datasource) {
-      // Extract the second-level values of the two-dimensional array (i.e., the
-      // combined item IDs) and log a warning reporting their absence.
+      // Extract the second-level values of the two-dimensional array (that is,
+      // the combined item IDs) and log a warning reporting their absence.
       $missing_ids = array_reduce(array_map('array_values', $items_by_datasource), 'array_merge', array());
       $args['%index'] = $this->label();
       $args['@items'] = '"' . implode('", "', $missing_ids) . '"';
diff --git a/src/Form/IndexAddFieldsForm.php b/src/Form/IndexAddFieldsForm.php
index 050ce4c..95470df 100644
--- a/src/Form/IndexAddFieldsForm.php
+++ b/src/Form/IndexAddFieldsForm.php
@@ -392,7 +392,7 @@ class IndexAddFieldsForm extends EntityForm {
 
       // Don't allow indexing of properties with unmapped types. Also, prefer
       // a "parent.child" type mapping (taking into account the parent property
-      // for, e.g., text fields).
+      // for, for example, text fields).
       $type = $property->getDataType();
       if ($parent_child_type && !empty($type_mapping[$parent_child_type])) {
         $type = $parent_child_type;
diff --git a/src/Form/IndexFieldsForm.php b/src/Form/IndexFieldsForm.php
index 81c91ba..63bf859 100644
--- a/src/Form/IndexFieldsForm.php
+++ b/src/Form/IndexFieldsForm.php
@@ -207,7 +207,7 @@ class IndexFieldsForm extends EntityForm {
     $form['#title'] = $this->t('Manage fields for search index %label', array('%label' => $index->label()));
     $form['#tree'] = TRUE;
 
-    $form['description']['#markup'] = $this->t('<p>The data type of a field determines how it can be used for searching and filtering. The boost is used to give additional weight to certain fields, e.g. titles or tags.</p> <p>For information about the data types available for indexing, see the <a href="@url">data types table</a> at the bottom of the page.</p>', array('@url' => '#search-api-data-types-table'));
+    $form['description']['#markup'] = $this->t('<p>The data type of a field determines how it can be used for searching and filtering. The boost is used to give additional weight to certain fields, for example titles or tags.</p> <p>For information about the data types available for indexing, see the <a href="@url">data types table</a> at the bottom of the page.</p>', array('@url' => '#search-api-data-types-table'));
     if ($index->hasValidServer()) {
       $arguments = array(
         ':server-url' => $index->getServerInstance()->toUrl('canonical')->toString(),
diff --git a/src/IndexInterface.php b/src/IndexInterface.php
index fa34a05..e7a57bc 100644
--- a/src/IndexInterface.php
+++ b/src/IndexInterface.php
@@ -501,9 +501,9 @@ interface IndexInterface extends ConfigEntityInterface {
   /**
    * Indexes some objects on this index.
    *
-   * Will return the IDs of items that were marked as indexed – i.e., items that
-   * were either rejected from indexing (by a processor or alter hook) or were
-   * successfully indexed.
+   * Will return the IDs of items that were marked as indexed – that is, items
+   * that were either rejected from indexing (by a processor or alter hook) or
+   * were successfully indexed.
    *
    * @param \Drupal\Core\TypedData\ComplexDataInterface[] $search_objects
    *   An array of search objects to be indexed, keyed by their item IDs.
@@ -599,7 +599,7 @@ interface IndexInterface extends ConfigEntityInterface {
    *
    * @throws \Drupal\search_api\SearchApiException
    *   Thrown if an internal error prevented the operation from succeeding.
-   *   E.g., if the tracker couldn't be loaded.
+   *   For example, if the tracker couldn't be loaded.
    */
   public function reindex();
 
diff --git a/src/Plugin/ConfigurablePluginInterface.php b/src/Plugin/ConfigurablePluginInterface.php
index c6bc793..ae71aa3 100644
--- a/src/Plugin/ConfigurablePluginInterface.php
+++ b/src/Plugin/ConfigurablePluginInterface.php
@@ -43,7 +43,7 @@ interface ConfigurablePluginInterface extends PluginInspectionInterface, Derivat
    *   etc.) and dependency name.
    *
    * @return bool
-   *   Whether the dependency was successfully removed from the plugin – i.e.,
+   *   Whether the dependency was successfully removed from the plugin – that is,
    *   after the configuration changes that were made, none of the removed
    *   items are dependencies of this plugin anymore.
    */
diff --git a/src/Plugin/IndexPluginBase.php b/src/Plugin/IndexPluginBase.php
index 08dae62..93b23dd 100644
--- a/src/Plugin/IndexPluginBase.php
+++ b/src/Plugin/IndexPluginBase.php
@@ -20,7 +20,7 @@ abstract class IndexPluginBase extends ConfigurablePluginBase implements IndexPl
    * {@inheritdoc}
    */
   public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
-    // @todo Change key to, e.g., '*index', to avoid potential collisions.
+    // @todo Change key to, for example, '*index', to avoid potential collisions.
     if (!empty($configuration['index']) && $configuration['index'] instanceof IndexInterface) {
       $this->setIndex($configuration['index']);
       unset($configuration['index']);
diff --git a/src/Plugin/search_api/datasource/ContentEntity.php b/src/Plugin/search_api/datasource/ContentEntity.php
index 236dbf1..373a1d7 100644
--- a/src/Plugin/search_api/datasource/ContentEntity.php
+++ b/src/Plugin/search_api/datasource/ContentEntity.php
@@ -714,9 +714,9 @@ class ContentEntity extends DatasourcePluginBase implements EntityDatasourceInte
 
     $configuration = $this->getConfiguration();
 
-    // If "default" is TRUE (i.e., "All except those selected"), remove all the
-    // selected bundles from the available ones to compute the indexed bundles.
-    // Otherwise, return all the selected bundles.
+    // If "default" is TRUE (that is, "All except those selected"),remove all
+    // the selected bundles from the available ones to compute the indexed
+    // bundles. Otherwise, return all the selected bundles.
     $bundles = array();
     $entity_bundles = $this->getEntityBundles();
     $selected_bundles = array_flip($configuration['bundles']['selected']);
diff --git a/src/Plugin/search_api/processor/Highlight.php b/src/Plugin/search_api/processor/Highlight.php
index 0838136..da8e795 100644
--- a/src/Plugin/search_api/processor/Highlight.php
+++ b/src/Plugin/search_api/processor/Highlight.php
@@ -512,7 +512,7 @@ class Highlight extends ProcessorPluginBase {
    *   The search keywords entered by the user.
    * @param bool $html
    *   (optional) Whether the text can contain HTML tags or not. In the former
-   *   case, text inside tags (i.e., tag names and attributes) won't be
+   *   case, text inside tags (that is, tag names and attributes) won't be
    *   highlighted.
    *
    * @return string
diff --git a/src/Plugin/search_api/processor/HtmlFilter.php b/src/Plugin/search_api/processor/HtmlFilter.php
index 844912a..36c9bcd 100644
--- a/src/Plugin/search_api/processor/HtmlFilter.php
+++ b/src/Plugin/search_api/processor/HtmlFilter.php
@@ -17,7 +17,7 @@ use Symfony\Component\Yaml\Parser;
  * @SearchApiProcessor(
  *   id = "html_filter",
  *   label = @Translation("HTML filter"),
- *   description = @Translation("Strips HTML tags from fulltext fields and decodes HTML entities. Use this processor when indexing HTML data, e.g., node bodies for certain text formats. The processor also allows to boost (or ignore) the contents of specific elements."),
+ *   description = @Translation("Strips HTML tags from fulltext fields and decodes HTML entities. Use this processor when indexing HTML data, for example, node bodies for certain text formats. The processor also allows to boost (or ignore) the contents of specific elements."),
  *   stages = {
  *     "preprocess_index" = -10,
  *     "preprocess_query" = -10
diff --git a/src/Plugin/search_api/processor/Property/RenderedItemProperty.php b/src/Plugin/search_api/processor/Property/RenderedItemProperty.php
index c7b965b..88cb8c3 100644
--- a/src/Plugin/search_api/processor/Property/RenderedItemProperty.php
+++ b/src/Plugin/search_api/processor/Property/RenderedItemProperty.php
@@ -46,7 +46,7 @@ class RenderedItemProperty extends ConfigurablePropertyBase {
 
     $form['view_mode'] = array(
       '#type' => 'item',
-      '#description' => $this->t('You can choose the view modes to use for rendering the items of different datasources and bundles. We recommend using a dedicated view mode (e.g., the "Search index" view mode available by default for content) to make sure that only relevant data (especially no field labels) will be included in the index.'),
+      '#description' => $this->t('You can choose the view modes to use for rendering the items of different datasources and bundles. We recommend using a dedicated view mode (for example, the "Search index" view mode available by default for content) to make sure that only relevant data (especially no field labels) will be included in the index.'),
     );
 
     $options_present = FALSE;
diff --git a/src/Plugin/search_api/processor/Tokenizer.php b/src/Plugin/search_api/processor/Tokenizer.php
index a5677ec..89456b6 100644
--- a/src/Plugin/search_api/processor/Tokenizer.php
+++ b/src/Plugin/search_api/processor/Tokenizer.php
@@ -212,8 +212,8 @@ class Tokenizer extends FieldsProcessorPluginBase {
     // To improve searching for numerical data such as dates, IP addresses or
     // version numbers, we consider a group of numerical characters separated
     // only by punctuation characters to be one piece. This also means that
-    // searching for e.g. '20/03/1984' also returns results with '20-03-1984'
-    // in them.
+    // searching for for example '20/03/1984' also returns results with
+    // '20-03-1984' in them.
     // Readable regular expression: "([number]+)[punctuation]+(?=[number])".
     $text = preg_replace('/([' . $this->getPregClassNumbers() . ']+)[' . $this->getPregClassPunctuation() . ']+(?=[' . $this->getPregClassNumbers() . '])/u', '\1', $text);
 
diff --git a/src/Plugin/views/field/SearchApiEntityField.php b/src/Plugin/views/field/SearchApiEntityField.php
index fa8b790..4e2e256 100644
--- a/src/Plugin/views/field/SearchApiEntityField.php
+++ b/src/Plugin/views/field/SearchApiEntityField.php
@@ -120,7 +120,7 @@ class SearchApiEntityField extends Field {
   /**
    * Retrieves the keys of the options defined by our direct parent.
    *
-   * I.e., this will exclude all options defined by
+   * That is, this will exclude all options defined by
    * \Drupal\views\Plugin\views\field\FieldPluginBase, and only include those
    * defined by \Drupal\views\Plugin\views\field\Field.
    *
@@ -182,10 +182,10 @@ class SearchApiEntityField extends Field {
     $this->fallbackHandler->buildOptionsForm($fallback_form, $form_state);
     // Remove all fields from FieldPluginBase from the fallback form, but leave
     // those in that were only added by our immediate parent,
-    // \Drupal\views\Plugin\views\field\Field. (E.g., the "type" option is
-    // especially prone to conflicts here.) The others come from the plugin base
-    // classes and will be identical, so it would be confusing to include them
-    // twice.
+    // \Drupal\views\Plugin\views\field\Field. (For example, the "type" option
+    // is especially prone to conflicts here.) The others come from the plugin
+    // base classes and will be identical, so it would be confusing to include
+    // them twice.
     $parent_keys[] = '#pre_render';
     $remove_from_fallback = array_diff_key($form, array_flip($parent_keys));
     $fallback_form = array_diff_key($fallback_form, $remove_from_fallback);
diff --git a/src/Plugin/views/field/SearchApiFieldTrait.php b/src/Plugin/views/field/SearchApiFieldTrait.php
index 3397a9e..0abdd8e 100644
--- a/src/Plugin/views/field/SearchApiFieldTrait.php
+++ b/src/Plugin/views/field/SearchApiFieldTrait.php
@@ -382,10 +382,10 @@ trait SearchApiFieldTrait {
                 }
               }
               catch (\InvalidArgumentException $e) {
-                // This can easily happen, e.g., when requesting a field that
-                // only exists on a different bundle. Unfortunately, there is no
-                // ComplexDataInterface::hasProperty() method, so we can only
-                // catch and ignore the exception.
+                // This can easily happen, for example, when requesting a field
+                // that only exists on a different bundle. Unfortunately, there
+                // is no ComplexDataInterface::hasProperty() method, so we can
+                // only catch and ignore the exception.
               }
             }
           }
diff --git a/src/Processor/ProcessorInterface.php b/src/Processor/ProcessorInterface.php
index 89d2029..862ada7 100644
--- a/src/Processor/ProcessorInterface.php
+++ b/src/Processor/ProcessorInterface.php
@@ -136,8 +136,8 @@ interface ProcessorInterface extends IndexPluginInterface {
   /**
    * Preprocesses the search index entity before it is saved.
    *
-   * This can, e.g., be used to make sure fields needed by this processor are
-   * enabled on the index.
+   * This can, for example, be used to make sure fields needed by this processor
+   * are enabled on the index.
    */
   public function preIndexSave();
 
diff --git a/src/Query/ConditionGroupInterface.php b/src/Query/ConditionGroupInterface.php
index 2c746c7..e1beb82 100644
--- a/src/Query/ConditionGroupInterface.php
+++ b/src/Query/ConditionGroupInterface.php
@@ -26,7 +26,7 @@ interface ConditionGroupInterface extends ConditionSetInterface {
    *   simple condition, represented as an object of type
    *   \Drupal\search_api\Query\ConditionInterface, or a nested condition group,
    *   represented by a \Drupal\search_api\Query\ConditionGroupInterface object.
-   *   Returned by reference so it's possible to, e.g., remove conditions.
+   *   Returned by reference so it's possible to, for example, remove conditions.
    */
   public function &getConditions();
 
@@ -46,8 +46,8 @@ interface ConditionGroupInterface extends ConditionSetInterface {
    *
    * @return string[]
    *   The tags associated with this condition group, as both the array keys and
-   *   values. Returned by reference so it's possible to, e.g., remove existing
-   *   tags.
+   *   values. Returned by reference so it's possible to, for example, remove
+   *   existing tags.
    */
   public function &getTags();
 
diff --git a/src/Query/ConditionSetInterface.php b/src/Query/ConditionSetInterface.php
index 6af5c50..7388ce6 100644
--- a/src/Query/ConditionSetInterface.php
+++ b/src/Query/ConditionSetInterface.php
@@ -11,7 +11,7 @@ interface ConditionSetInterface {
    * Adds a new ($field $operator $value) condition.
    *
    * @param string $field
-   *   The ID of the field to filter on, e.g. "title". The special fields
+   *   The ID of the field to filter on, for example "title". The special fields
    *   "search_api_datasource" (filter by datasource ID) and
    *   "search_api_language" (filter by language code) can be used in addition
    *   to all indexed fields on the index. However, for filtering on language
diff --git a/src/Query/Query.php b/src/Query/Query.php
index 4cfc7e6..112501e 100644
--- a/src/Query/Query.php
+++ b/src/Query/Query.php
@@ -171,7 +171,7 @@ class Query implements QueryInterface {
       'name' => $this->t('Multiple terms'),
       'description' => $this->t('The query is interpreted as multiple keywords separated by spaces. Keywords containing spaces may be "quoted". Quoted keywords must still be separated by spaces.'),
     );
-    // @todo Add fourth mode for complicated expressions, e.g.: »"vanilla ice" OR (love NOT hate)«
+    // @todo Add fourth mode for complicated expressions, for example: »"vanilla ice" OR (love NOT hate)«
     return $modes;
   }
 
diff --git a/src/Query/QueryInterface.php b/src/Query/QueryInterface.php
index fb8b3d2..83eb34b 100644
--- a/src/Query/QueryInterface.php
+++ b/src/Query/QueryInterface.php
@@ -214,8 +214,8 @@ interface QueryInterface extends ConditionSetInterface {
    * operations before the query is passed to the server's search() method.
    *
    * @throws \Drupal\search_api\SearchApiException
-   *   Thrown if any wrong options were set on the query (e.g., conditions or
-   *   sorts on unknown fields).
+   *   Thrown if any wrong options were set on the query (for example,conditions
+   *   or sorts on unknown fields).
    */
   public function preExecute();
 
@@ -248,12 +248,12 @@ interface QueryInterface extends ConditionSetInterface {
    *   type, and search strings or nested expression arrays at numeric keys.
    *   Additionally, a '#negation' key might be present, which means – unless it
    *   maps to a FALSE value – that the search keys contained in that array
-   *   should be negated, i.e. not be present in returned results. The negation
-   *   works on the whole array, not on each contained term individually – i.e.,
-   *   with the "AND" conjunction and negation, only results that contain all
-   *   the terms in the array should be excluded; with the "OR" conjunction and
-   *   negation, all results containing one or more of the terms in the array
-   *   should be excluded.
+   *   should be negated, that is not be present in returned results. The
+   *   negation works on the whole array, not on each contained term individually
+   *   – that is,with the "AND" conjunction and negation, only results that
+   *   contain all the terms in the array should be excluded; with the "OR"
+   *   conjunction and negation, all results containing one or more of the terms
+   *   in the array should be excluded.
    *
    * @see keys()
    */
@@ -419,8 +419,8 @@ interface QueryInterface extends ConditionSetInterface {
    *
    * @return string[]
    *   The tags associated with this search query, as both the array keys and
-   *   values. Returned by reference so it's possible to, e.g., remove existing
-   *   tags.
+   *   values. Returned by reference so it's possible to, for example, remove
+   *   existing tags.
    */
   public function &getTags();
 
diff --git a/src/Query/ResultSetInterface.php b/src/Query/ResultSetInterface.php
index cfffa9d..aebf6b3 100644
--- a/src/Query/ResultSetInterface.php
+++ b/src/Query/ResultSetInterface.php
@@ -105,7 +105,7 @@ interface ResultSetInterface extends \Traversable {
    *
    * @return string[]
    *   A numeric array of search keys that were ignored for this search
-   *   (e.g., because of being too short or stop words).
+   *   (for example, because of being too short or stop words).
    */
   public function getIgnoredSearchKeys();
 
diff --git a/src/Task/TaskManager.php b/src/Task/TaskManager.php
index b57e0e4..0097449 100644
--- a/src/Task/TaskManager.php
+++ b/src/Task/TaskManager.php
@@ -202,7 +202,7 @@ class TaskManager implements TaskManagerInterface {
    */
   public function executeAllTasks(array $conditions = array(), $limit = NULL) {
     // We have to use this roundabout way because tasks, during their execution,
-    // might create additional tasks. (E.g., see
+    // might create additional tasks. (For example, see
     // \Drupal\search_api\Task\IndexTaskManager::trackItems().)
     $executed = 0;
     while (TRUE) {
diff --git a/src/Tracker/TrackerInterface.php b/src/Tracker/TrackerInterface.php
index 6912e8f..71060b4 100644
--- a/src/Tracker/TrackerInterface.php
+++ b/src/Tracker/TrackerInterface.php
@@ -11,7 +11,7 @@ use Drupal\search_api\Plugin\IndexPluginInterface;
  * in the index, which have changed since they were last indexed, etc.
  *
  * The tracker is required to ignore calls to tracking methods for item IDs that
- * won't have any effect – i.e., inserting items which are already known, or
+ * won't have any effect – that is, inserting items which are already known, or
  * marking items as indexed, updated or deleted that are not.
  *
  * @see \Drupal\search_api\Annotation\SearchApiTracker
diff --git a/src/Utility.php b/src/Utility.php
index 1585562..ad1f3f2 100644
--- a/src/Utility.php
+++ b/src/Utility.php
@@ -716,7 +716,7 @@ class Utility {
    * rather weird. Therefore, this method should be used when making a copy of
    * such an array, or of an array containing references.
    *
-   * This method will also omit empty array elements (i.e., elements that
+   * This method will also omit empty array elements (that is, elements that
    * evaluate to FALSE according to PHP's native rules).
    *
    * @param array $array
@@ -782,7 +782,7 @@ class Utility {
    * @return array
    *   A numeric array, containing the datasource ID in element 0 and the raw
    *   item ID or property path in element 1. In the case of
-   *   datasource-independent properties (i.e., when there is no prefix),
+   *   datasource-independent properties (that is, when there is no prefix),
    *   element 0 will be NULL.
    */
   public static function splitCombinedId($combined_id) {
diff --git a/tests/search_api_test/src/TestPluginTrait.php b/tests/search_api_test/src/TestPluginTrait.php
index 298e9b6..6deb090 100644
--- a/tests/search_api_test/src/TestPluginTrait.php
+++ b/tests/search_api_test/src/TestPluginTrait.php
@@ -76,7 +76,7 @@ trait TestPluginTrait {
   /**
    * Returns the plugin type of this object.
    *
-   * Equivalent to the last part of the namespace, i.e., without the module
+   * Equivalent to the last part of the namespace, that is, without the module
    * prefix.
    *
    * @return string
diff --git a/tests/src/Kernel/DependencyRemovalTest.php b/tests/src/Kernel/DependencyRemovalTest.php
index af0c2d9..64f5817 100644
--- a/tests/src/Kernel/DependencyRemovalTest.php
+++ b/tests/src/Kernel/DependencyRemovalTest.php
@@ -467,7 +467,7 @@ class DependencyRemovalTest extends KernelTestBase {
       ->save();
 
     // Disabling modules in Kernel tests normally doesn't trigger any kind of
-    // reaction, just removes it from the list of modules (e.g., to avoid
+    // reaction, just removes it from the list of modules (For example, to avoid
     // calling of a hook). Therefore, we have to trigger that behavior
     // ourselves.
     \Drupal::getContainer()->get('config.manager')->uninstall('module', 'search_api_test');
diff --git a/tests/src/Kernel/Processor/RenderedItemTest.php b/tests/src/Kernel/Processor/RenderedItemTest.php
index 0ecad6a..cf7a3e6 100644
--- a/tests/src/Kernel/Processor/RenderedItemTest.php
+++ b/tests/src/Kernel/Processor/RenderedItemTest.php
@@ -153,12 +153,12 @@ class RenderedItemTest extends ProcessorTestBase {
       $field = $item->getField('rendered_item');
       $this->assertEquals('text', $field->getType(), 'Node item ' . $nid . ' rendered value is identified as text.');
       $values = $field->getValues();
-      // Test that the value is a string (not, e.g., a SafeString object).
+      // Test that the value is a string (not, for example, a SafeString object).
       $this->assertTrue(is_string($values[0]), 'Node item ' . $nid . ' rendered value is a string.');
       $this->assertEquals(1, count($values), 'Node item ' . $nid . ' rendered value is a single value.');
       // These tests rely on the template not changing. However, if we'd only
       // check whether the field values themselves are included, there could
-      // easier be false positives. For example the title text was present even
+      // easier be false positives. For example, the title text was present even
       // when the processor was broken, because the schema metadata was also
       // adding it to the output.
       $this->assertTrue(substr_count($values[0], 'view-mode-full') > 0, 'Node item ' . $nid . ' rendered in view-mode "full".');

diff --git a/search_api_db/src/Plugin/search_api/backend/Database.php b/search_api_db/src/Plugin/search_api/backend/Database.php
index 130df0c..c6e82ce 100644
--- a/search_api_db/src/Plugin/search_api/backend/Database.php
+++ b/search_api_db/src/Plugin/search_api/backend/Database.php
@@ -428,7 +428,7 @@ class Database extends BackendPluginBase {
     $form['partial_matches'] = array(
       '#type' => 'checkbox',
       '#title' => $this->t('Search on parts of a word'),
-      '#description' => $this->t('Find keywords in parts of a word, too. (E.g., find results with "database" when searching for "base"). <strong>Caution:</strong> This can make searches much slower on large sites!'),
+      '#description' => $this->t('Find keywords in parts of a word, too. (For example, find results with "database" when searching for "base"). <strong>Caution:</strong> This can make searches much slower on large sites!'),
       '#default_value' => $this->configuration['partial_matches'],
     );
 
@@ -814,7 +814,7 @@ class Database extends BackendPluginBase {
    *   TRUE if the data needs to be reindexed, FALSE otherwise.
    *
    * @throws \Drupal\search_api\SearchApiException
    *   Thrown if any exceptions occur internally, e.g., in the database
    *   layer.
    */
   protected function fieldsUpdated(IndexInterface $index) {
@@ -1188,7 +1188,8 @@ class Database extends BackendPluginBase {
             // Taken from core search to reflect less importance of words later
             // in the text.
             // Focus is a decaying value in terms of the amount of unique words
             // up to this point. From 100 words and more, it decays, to e.g. 0.5
             // at 500 words and 0.3 at 1000 words.
             $score *= min(1, .01 + 3.5 / (2 + count($unique_tokens) * .015));
 
@@ -814,7 +814,7 @@ class Database extends BackendPluginBase {
    *
    * @throws \Drupal\search_api\SearchApiException
-   *   Thrown if any exceptions occur internally, e.g., in the database
+   *   Thrown if any exceptions occur internally, for example, in the database
    *   layer.
    */
@@ -1188,7 +1188,8 @@ class Database extends BackendPluginBase {
             // in the text.
             // Focus is a decaying value in terms of the amount of unique words
-            // up to this point. From 100 words and more, it decays, to e.g. 0.5
+            // up to this point. From 100 words and more, it decays, to for
+            // example 0.5
             // at 500 words and 0.3 at 1000 words.
             $score *= min(1, .01 + 3.5 / (2 + count($unique_tokens) * .015));
diff --git a/src/Plugin/views/query/SearchApiQuery.php b/src/Plugin/views/query/SearchApiQuery.php
index 187729f..32e81f2 100644
--- a/src/Plugin/views/query/SearchApiQuery.php
+++ b/src/Plugin/views/query/SearchApiQuery.php
@@ -286,7 +286,7 @@ class SearchApiQuery extends QueryPluginBase {
     $form['bypass_access'] = array(
       '#type' => 'checkbox',
       '#title' => $this->t('Bypass access checks'),
-      '#description' => $this->t('If the underlying search index has access checks enabled (e.g., through the "Content access" processor), this option allows you to disable them for this view. This will never disable any filters placed on this view.'),
+      '#description' => $this->t('If the underlying search index has access checks enabled (for example, through the "Content access" processor), this option allows you to disable them for this view. This will never disable any filters placed on this view.'),
       '#default_value' => $this->options['bypass_access'],
     );
 
@@ -796,7 +796,7 @@ class SearchApiQuery extends QueryPluginBase {
    * Adds a new ($field $operator $value) condition filter.
    *
    * @param string $field
    *   The field to filter on, e.g. 'title'. The special field
    *   "search_api_datasource" can be used to filter by datasource ID.
    * @param mixed $value
    *   The value the field should have (or be related to by the operator).
@@ -1115,12 +1115,12 @@ class SearchApiQuery extends QueryPluginBase {
    *   type, and search strings or nested expression arrays at numeric keys.
    *   Additionally, a '#negation' key might be present, which means – unless it
    *   maps to a FALSE value – that the search keys contained in that array
-   *   should be negated, i.e. not be present in returned results. The negation
-   *   works on the whole array, not on each contained term individually – i.e.,
-   *   with the "AND" conjunction and negation, only results that contain all
-   *   the terms in the array should be excluded; with the "OR" conjunction and
-   *   negation, all results containing one or more of the terms in the array
-   *   should be excluded.
+   *   should be negated, that is not be present in returned results. The
+   *   negation works on the whole array, not on each contained term individually
+   *   – that is, with the "AND" conjunction and negation, only results that
+   *   contain all the terms in the array should be excluded; with the "OR"
+   *   conjunction and negation, all results containing one or more of the terms
+   *   in the array should be excluded.
    *
    * @see keys()
    *
@@ -796,7 +796,7 @@ class SearchApiQuery extends QueryPluginBase {
    *
    * @param string $field
-   *   The field to filter on, e.g. 'title'. The special field
+   *   The field to filter on, for example 'title'. The special field
    *   "search_api_datasource" can be used to filter by datasource ID.
    * @param mixed $value